@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,11 +28,11 @@ import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
 
 /**
- * Class testing the default instantiator. I'm cheating a little bit here since
+ * Class testing the default instantiator. I'm cheating a little here since
  * I'm not unit testing directly the class. The reason I'm doing this is that I
- * want to make sure it works well with the cglib class and not the actual
+ * want to make sure it works well with the ByteBuddy class and not the actual
  * mocked class.
- * 
+ *
  * @author Henri Tremblay
  */
 public class DefaultClassInstantiatorTest {
@@ -194,11 +194,13 @@ public class DefaultClassInstantiatorTest {
     }
 
     @Test
+    @Ignore("requires --add-opens java.base/java.io=ALL-UNNAMED with Java 9+")
     public void serializable() {
         checkInstantiation(SerializableClass.class);
     }
 
     @Test
+    @Ignore("requires --add-opens java.base/java.io=ALL-UNNAMED with Java 9+")
     public void badSerializable() throws Exception {
         DefaultClassInstantiator instantiator = new DefaultClassInstantiator();
         assertTrue(instantiator.newInstance(BadlyDoneSerializableClass.class) instanceof BadlyDoneSerializableClass);
