@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ import static org.junit.Assert.*;
  */
 public class FinalEqualsTest {
 
-    static class MyInt {
+    public static class MyInt {
         private final int i;
 
         public MyInt(int i) {
