@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -47,8 +47,7 @@ public class IMockBuilderTest {
     }
     @Test
     public void testMock() {
-        IMockBuilderTest mock = builder.mock();
-        assertMock(mock, null, MockType.DEFAULT);
+        IMockBuilderTest mock = builder.mock();assertMock(mock, null, MockType.DEFAULT);
     }
 
     @Test
