@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -67,9 +67,9 @@ public abstract class EasyMockAnnotationsTest extends EasyMockSupport {
         assertEquals("1", standardMock.oneArg(true));
         assertEquals("2", namedMock.oneArg(true));
         verifyAll();
-        assertEquals("EasyMock for interface org.easymock.tests.IMethods", standardMock.toString());
+        assertEquals("EasyMock for field org.easymock.tests2.EasyMockAnnotationsTest.standardMock", standardMock.toString());
         assertEquals("name1", namedMock.toString());
-        assertEquals("EasyMock for interface org.easymock.tests.IMethods", typedMock.toString());
+        assertEquals("EasyMock for field org.easymock.tests2.EasyMockAnnotationsTest.typedMock", typedMock.toString());
         assertEquals("name2", namedAndTypedMock.toString());
     }
 
