@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -54,7 +54,7 @@ public class MockedExceptionTest {
         replay(c, expected);
 
         try {
-            c.length(); // fillInStackTrace wont' be called internally
+            c.length(); // fillInStackTrace won't be called internally
         } catch (RuntimeException actual) {
             assertSame(myException, actual.fillInStackTrace()); // so the fillInStackTrace recording is still valid
             assertSame(expected, actual);
@@ -65,7 +65,7 @@ public class MockedExceptionTest {
 
     private static int check = 2;
 
-    private static class MyException extends RuntimeException {
+    public static class MyException extends RuntimeException {
         private static final long serialVersionUID = 1L;
 
         @Override
