@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2021 the original author or authors.
+ * Copyright 2001-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -83,14 +83,4 @@ public class NameTest {
         }
     }
 
-    @Test
-    public void shouldThrowIllegalArgumentExceptionIfNameIsNoValidJavaIdentifier() {
-        try {
-            createMock("no-valid-java-identifier", IMethods.class);
-            throw new AssertionError();
-        } catch (IllegalArgumentException expected) {
-            assertEquals("'no-valid-java-identifier' is not a valid Java identifier.", expected.getMessage());
-        }
-    }
-
 }
