@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2021 the original author or authors.
+ * Copyright 2015-2022 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -49,7 +49,7 @@ public class FilteringRule implements TestRule {
 
 class FilteringClassLoader extends ClassLoader {
 
-    private static final String[] packagesToBeDeferred = new String[] { "org.hamcrest.", "java.", "sun.",
+    private static final String[] packagesToBeDeferred = new String[] { "org.hamcrest.", "java.", "jdk.", "sun.",
             "org.junit." };
 
     private final Collection<String> ignoredPackages;
